/**
 * 小程序
 * 首页基础数据
 */

import * as partyMemberData from '../../data/partyMember';
import * as partyInformationData from '../../data/partyInformation';
import * as configEnum from "../../config/enum";
import * as splitResultConfig from "../../config/splitResultConfig";
import { extractData } from '../../util/piecemeal';
import { changeEnumValue, eccEnumValue } from '../../util/verificationEnum';
import { BizError } from '../../util/bizError';
import { ERRORENUM } from '../../config/errorEnum';


/**
 * 主页基础数据
 */
export async function homeData() {
    /**主页基础数据 */
    let baseInfo:any = {};

    /**党员总数 */
    let partyMemberNum = await partyMemberData.groupFindPartyMemberCount({});
    /**党建指令指数 */
    let massIndex = 87.6;

    /**党内职务人员 */
    let branchSecretary = getPartyPositions(configEnum.PARTYPOSITIONS.支部书记);
    let deputySecretary = getPartyPositions(configEnum.PARTYPOSITIONS.支部副书记);
    let memberOrganization = getPartyPositions(configEnum.PARTYPOSITIONS.组织委员);
    let memberAdvocacy = getPartyPositions(configEnum.PARTYPOSITIONS.宣传委员);
    let disciplineInspection = getPartyPositions(configEnum.PARTYPOSITIONS.纪检委员);

    baseInfo = {
        partyMemberNum,
        massIndex,
        partyPositions: [
            {
                key: "支部书记",
                list: branchSecretary
            },
            {
                key: "支部副书记",
                list: deputySecretary
            },
            {
                key: "组织委员",
                list: memberOrganization
            },
            {
                key: "宣传委员",
                list: memberAdvocacy
            },
            {
                key: "纪检委员",
                list: disciplineInspection
            }
        ]
    }

    return baseInfo;
}


/**
 * 根据党建职务查询当职人员
 * @param type 党建职务
 * @returns ["李一", "王二"] 当职人员姓名
 */
async function getPartyPositions(type) {
    let result:any = [];
    let dataInfo = await partyMemberData.getBaseListByPartyPositions(type);
    if (!dataInfo) throw new BizError(ERRORENUM.未找到数据, `查询党建职务时 ${type} 不存在`);
    dataInfo.forEach( info => {
        result.push(info.name);
    })

    return result;
}


/**
 * 根据资讯类型查询党建资讯列表
 * @param informationType 党建资讯类型
 * @returns 
 */
export async function informationData(informationType) {
    let selectParam:any = {};
    if (informationType) {
        eccEnumValue("党建资讯列表查询", "资讯类型", configEnum.INFORMATIONTYPE, informationType);
        selectParam.informationType = informationType;
    }

    /**医院文化 */
    let partyInformationInfo = await partyInformationData.findPartyInformationList(selectParam);
    if (!partyInformationInfo) throw new BizError(ERRORENUM.未找到数据, `查询党建资讯时 ${selectParam.informationType} 不存在`);
    let dataList = [];
    partyInformationInfo.forEach( info => {
        let changeData:any = extractData(splitResultConfig.partyInformationConfig, info, true);
        changeData.informationType = changeEnumValue(configEnum.INFORMATIONTYPE, changeData.informationType);

        dataList.push(changeData);
    })

    return dataList;
}



